# Label Link Formatter

Add attributes to entity reference label links.

## Usage
1. On your "Manage Display" page, configure your entity reference fields to use the "Lable with link attributes" formatter.
2. Set your attributes as a string (quotes and all)
  E.g. `class="my-class another-class" target="_blank" data-mydata="datapoint"`
3. The defined attributes will be merged any existing attributes and displayed on the anchor itself.

## Installation

1. run `composer require drupal/label_link_attributes`
2. run `drush en label_link_attributes`

## Committing

This project uses the conventional commit standard, which means your commits should follow a basic template of:

    <type>[optional scope]: <description>

    [optional body]

    [optional footer(s)]

For more detailed information about available types, scopes, breaking changes, etc. please see the [official documentation](https://www.conventionalcommits.org/en/v1.0.0/).

This project also provides a command to assist you in formatting  commit messages using [commitizen](https://commitizen.github.io/cz-cli/):

```bash
npm run commit
```

## Versioning

This project uses Semantic Versioning 2.0.0 to keep track of releases.

    Given a version number MAJOR.MINOR.PATCH, increment the:

    1. MAJOR version when you make incompatible API changes,
    2. MINOR version when you add functionality in a backward compatible manner, and
    3. PATCH version when you make backwards compatible bug fixes.

    Additional labels for pre-release and build metadata are available as extensions to the MAJOR.MINOR.PATCH format.

For more detailed information about SemVer, please see the [official documentation](https://semver.org/).

When making a release, you should use the provided command:

```bash
npm run release
```

This command uses [standard-version](https://github.com/conventional-changelog/standard-version) to parse through your commits, decide what kind of release will be created, and automatically generates a CHANGELOG.md file for your project. These changes are then commited using the message `chore(release): <version number>`.

Once that is done, you can simply run `git push --follow-tags origin` to have your release pushed up to the repository.

## Building the Module

This project provides 2 different types of builds for the module.

### Production

```bash
npm run build
npm run build:prod
```

Compiles and minifies all custom js/css code and removes the node_modules/vendor/bin directories.

### Development

```bash
npm run build:dev
```

Lints, compiles, and minifies all custom js/css code

## Running code checks

This project provides a few different kinds of code checks.

### PHP

```bash
npm run lint
npm run lint:php
```

Runs PHPCS using the Drupal/DrupalPractice standards.

## Fixing Code Violations

This project provides commands to run an automated fix for code check failures.

### PHP

```bash
npm run lint:fix
npm run lint:php:fix
```

Runs PHPCBF using Drupal/DrupalPractice standards.

## Cleaning the directory

```bash
npm run clean
```

Removes directories generated by npm/composer.
